==> owncloud-10.2.0.zip: owncloud/apps/files/l10n/az.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "İnformasiya daşıyıcısı yalnışdır",
    "Unknown error" : "Bəlli olmayan səhv baş verdi",
    "All files" : "Bütün fayllar",
    "Saved" : "Saxlanıldı",
    "Home" : "Ev",
    "Close" : "Bağla",
    "Favorites" : "Sevimlilər",
    "Upload cancelled." : "Yüklənmə dayandırıldı.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Yükləmək olmur {filename} ona görə ki, ya qovluqdur yada ki, həcmi 0 baytdır ",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Kifayət qədər boş yer yoxdur, siz yükləyirsiniz {size1} ancaq  {size2} var. ",
    "Uploading..." : "Serverə yüklənir...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Faylın yüklənməsi gedir. Əgər səhifəni indi tərk etsəniz yüklənmə dayanacaq.",
    "Actions" : "İşlər",
    "Download" : "Yüklə",
    "Rename" : "Adı dəyiş",
    "Delete" : "Sil",
    "Disconnect storage" : "Daşıyıcını ayır",
    "Unshare" : "Paylaşımı durdur",
    "Files" : "Fayllar",
    "Details" : "Detallar",
    "Select" : "Seç",
    "Pending" : "Gözləmə",
    "Unable to determine date" : "Tarixi təyin etmək mümkün olmadı",
    "Invalid path" : "Yalnış ünvan",
    "This operation is forbidden" : "Bu əməliyyat qadağandır",
    "This directory is unavailable, please check the logs or contact the administrator" : "Bu qovluq tapılmir. Xahiş olunur jurnalları yoxlayın ya da inzibatçı ilə əlaqə saxlayın",
    "Name" : "Ad",
    "Size" : "Həcm",
    "Modified" : "Dəyişdirildi",
    "_%n folder_::_%n folders_" : ["%n qovluq","%n qovluqlar"],
    "_%n file_::_%n files_" : ["%n fayllar","%n fayllar"],
    "{dirs} and {files}" : "{dirs} və {files}",
    "You don’t have permission to upload or create files here" : "Sizin burda yükləməyə və ya fayl yaratmağa yetkiniz yoxdur  ",
    "_Uploading %n file_::_Uploading %n files_" : ["%n fayllar yüklənilir","%n fayllar yüklənilir"],
    "New" : "Yeni",
    "\"{name}\" is an invalid file name." : "\"{name}\" yalnış fayl adıdır.",
    "File name cannot be empty." : "Faylın adı boş ola bilməz.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} məlumat anbarı doludur, fayllar artıq yenilənə və ya sinxronizasiya edilə bilməz!",
    "Your storage is full, files can not be updated or synced anymore!" : "Sizin deponuz doludur, fayllar artıq yenilənə və sinxronizasiya edilə bilməz!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} məlumat anbari demək olar ki, doludur ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Sizin depo depo demək olar ki, doludur ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["uyğun '{filter}'","uyğun '{filter}'"],
    "Path" : "Ünvan",
    "_%n byte_::_%n bytes_" : ["%n baytlar","%n bytes"],
    "Favorited" : "İstəkləndi",
    "Favorite" : "İstəkli",
    "Folder" : "Qovluq",
    "New folder" : "Yeni qovluq",
    "{newname} already exists" : "{newname} artıq mövcuddur",
    "Upload" : "Serverə yüklə",
    "An error occurred while trying to update the tags" : "Qeydlərin yenilənməsi müddətində səhv baş verdi ",
    "A new file or folder has been <strong>created</strong>" : "Yeni fayl və ya direktoriya <strong>yaradılmışdır</strong>",
    "A file or folder has been <strong>changed</strong>" : "Fayl və ya direktoriya <strong>dəyişdirilib</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>sevimli faylların</strong> yaradılması və silinməsi haqqında olan xəbərdarlıqları limitlə <em>(Yalnız axınlar)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Fayl və ya direktoriya <strong>silinib</strong>",
    "A file or folder has been <strong>restored</strong>" : "Fayl yada qovluq geriyə <strong>qaytarıldı</strong>",
    "You created %1$s" : "Siz yaratdınız %1$s",
    "%2$s created %1$s" : "%2$s yaradılmış %1$s",
    "%1$s was created in a public folder" : "%1$s ictimai qovluqda yaradıldı",
    "You changed %1$s" : "Siz dəyişdiniz %1$s",
    "%2$s changed %1$s" : "%2$s dəyişdirildi %1$s",
    "You deleted %1$s" : "Siz silindiniz %1$s",
    "%2$s deleted %1$s" : "%2$s silindi %1$s",
    "You restored %1$s" : "Siz qayıtdınız %1$s",
    "%2$s restored %1$s" : "%2$s bərpa edildi %1$s",
    "Upload (max. %s)" : "Yüklə (max. %s)",
    "File handling" : "Fayl emalı",
    "Maximum upload size" : "Maksimal yükləmə həcmi",
    "max. possible: " : "maks. ola bilər: ",
    "Save" : "Saxlamaq",
    "Settings" : "Quraşdırmalar",
    "WebDAV" : "WebDAV",
    "No files in here" : "Burda fayl yoxdur",
    "Upload some content or sync with your devices!" : "Bezi kontenti yüklə yada, öz avadanlıqlarınızla sinxronizasiya edin!",
    "No entries found in this folder" : "Bu qovluqda heç bir verilən tapılmadı",
    "Select all" : "Hamısıı seç",
    "Upload too large" : "Yüklənmə şox böyükdür",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Yükləmək istədiyiniz faylların həcmi, bu serverdə izin verilmiş maksimal yüklənmə həcmindən böyükdür.",
    "No favorites" : "Seçilmiş yoxdur",
    "Files and folders you mark as favorite will show up here" : "İstəkli qeyd etdiyiniz fayllar və qovluqlar burda göstəriləcək",
    "Text file" : "Tekst faylı",
    "New text file.txt" : "Yeni mətn file.txt",
    "Unknown user" : "Istifadəçi tanınmır "
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/files/l10n/az.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "İnformasiya daşıyıcısı yalnışdır",
    "Unknown error" : "Bəlli olmayan səhv baş verdi",
    "All files" : "Bütün fayllar",
    "Home" : "Ev",
    "Close" : "Bağla",
    "Favorites" : "Sevimlilər",
    "Upload cancelled." : "Yüklənmə dayandırıldı.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Yükləmək olmur {filename} ona görə ki, ya qovluqdur yada ki, həcmi 0 baytdır ",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Kifayət qədər boş yer yoxdur, siz yükləyirsiniz {size1} ancaq  {size2} var. ",
    "Uploading..." : "Serverə yüklənir...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Faylın yüklənməsi gedir. Əgər səhifəni indi tərk etsəniz yüklənmə dayanacaq.",
    "Actions" : "İşlər",
    "Download" : "Yüklə",
    "Rename" : "Adı dəyiş",
    "Delete" : "Sil",
    "Disconnect storage" : "Daşıyıcını ayır",
    "Unshare" : "Paylaşımı durdur",
    "Files" : "Fayllar",
    "Details" : "Detallar",
    "Select" : "Seç",
    "Pending" : "Gözləmə",
    "Unable to determine date" : "Tarixi təyin etmək mümkün olmadı",
    "Invalid path" : "Yalnış ünvan",
    "This operation is forbidden" : "Bu əməliyyat qadağandır",
    "This directory is unavailable, please check the logs or contact the administrator" : "Bu qovluq tapılmir. Xahiş olunur jurnalları yoxlayın ya da inzibatçı ilə əlaqə saxlayın",
    "group" : "qrup",
    "Remote share" : "Uzaq yayımlanma",
    "Name" : "Ad",
    "Size" : "Həcm",
    "Modified" : "Dəyişdirildi",
    "_%n folder_::_%n folders_" : ["%n qovluq","%n qovluqlar"],
    "_%n file_::_%n files_" : ["%n fayllar","%n fayllar"],
    "{dirs} and {files}" : "{dirs} və {files}",
    "You don’t have permission to upload or create files here" : "Sizin burda yükləməyə və ya fayl yaratmağa yetkiniz yoxdur  ",
    "_Uploading %n file_::_Uploading %n files_" : ["%n fayllar yüklənilir","%n fayllar yüklənilir"],
    "New" : "Yeni",
    "Unknown user" : "Istifadəçi tanınmır ",
    "\"{name}\" is an invalid file name." : "\"{name}\" yalnış fayl adıdır.",
    "File name cannot be empty." : "Faylın adı boş ola bilməz.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} məlumat anbarı doludur, fayllar artıq yenilənə və ya sinxronizasiya edilə bilməz!",
    "Your storage is full, files can not be updated or synced anymore!" : "Sizin deponuz doludur, fayllar artıq yenilənə və sinxronizasiya edilə bilməz!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} məlumat anbari demək olar ki, doludur ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Sizin depo depo demək olar ki, doludur ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["uyğun '{filter}'","uyğun '{filter}'"],
    "Path" : "Ünvan",
    "_%n byte_::_%n bytes_" : ["%n baytlar","%n bytes"],
    "Favorited" : "İstəkləndi",
    "Favorite" : "İstəkli",
    "Folder" : "Qovluq",
    "New folder" : "Yeni qovluq",
    "{newname} already exists" : "{newname} artıq mövcuddur",
    "Upload" : "Serverə yüklə",
    "An error occurred while trying to update the tags" : "Qeydlərin yenilənməsi müddətində səhv baş verdi ",
    "A new file or folder has been <strong>created</strong>" : "Yeni fayl və ya direktoriya <strong>yaradılmışdır</strong>",
    "A file or folder has been <strong>changed</strong>" : "Fayl və ya direktoriya <strong>dəyişdirilib</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "<strong>sevimli faylların</strong> yaradılması və silinməsi haqqında olan xəbərdarlıqları limitlə <em>(Yalnız axınlar)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Fayl və ya direktoriya <strong>silinib</strong>",
    "A file or folder has been <strong>restored</strong>" : "Fayl yada qovluq geriyə <strong>qaytarıldı</strong>",
    "You created %1$s" : "Siz yaratdınız %1$s",
    "%2$s created %1$s" : "%2$s yaradılmış %1$s",
    "%1$s was created in a public folder" : "%1$s ictimai qovluqda yaradıldı",
    "You changed %1$s" : "Siz dəyişdiniz %1$s",
    "%2$s changed %1$s" : "%2$s dəyişdirildi %1$s",
    "You deleted %1$s" : "Siz silindiniz %1$s",
    "%2$s deleted %1$s" : "%2$s silindi %1$s",
    "You restored %1$s" : "Siz qayıtdınız %1$s",
    "%2$s restored %1$s" : "%2$s bərpa edildi %1$s",
    "Upload (max. %s)" : "Yüklə (max. %s)",
    "Settings" : "Quraşdırmalar",
    "WebDAV" : "WebDAV",
    "No files in here" : "Burda fayl yoxdur",
    "Upload some content or sync with your devices!" : "Bezi kontenti yüklə yada, öz avadanlıqlarınızla sinxronizasiya edin!",
    "No entries found in this folder" : "Bu qovluqda heç bir verilən tapılmadı",
    "Select all" : "Hamısıı seç",
    "Upload too large" : "Yüklənmə şox böyükdür",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Yükləmək istədiyiniz faylların həcmi, bu serverdə izin verilmiş maksimal yüklənmə həcmindən böyükdür.",
    "No favorites" : "Seçilmiş yoxdur",
    "Files and folders you mark as favorite will show up here" : "İstəkli qeyd etdiyiniz fayllar və qovluqlar burda göstəriləcək",
    "Text file" : "Tekst faylı",
    "New text file.txt" : "Yeni mətn file.txt"
},
"nplurals=2; plural=(n != 1);");
